@@ -2,7 +2,7 @@
  * mc68ec.c -- Low level support for the Motorola mc68ec0x0 board.
  *             Written by rob@cygnus.com (Rob Savoye)
  *
- *  $Id: mc68ec.c,v 1.4 2007/06/22 14:07:55 joel Exp $
+ *  $Id$
  */
 
 #include "leds.h"
@@ -11,8 +11,7 @@
  * rtems_bsp_delay -- delay execution. This is an ugly hack. It should
  *          use the timer, but I'm waiting for docs. (sigh)
  */
-void rtems_bsp_delay(num)
-int num;
+void rtems_bsp_delay(int num)
 {
   while (num--)
     {
