@@ -81,12 +81,6 @@
     #error "Driver must have MCLBYTES > RBUF_SIZE"
 #endif
 
-typedef struct mcf5282BufferDescriptor_ {
-    volatile uint16_t   status;
-    uint16_t			length;
-    volatile void      *buffer;
-} mcf5282BufferDescriptor_t;
-
 /*
  * Per-device data
  */
@@ -118,7 +112,8 @@ struct mcf5282_enet_struct {
     /*
      * Link parameters
      */
-    int             force100Full;
+    enum            { link_auto, link_100Full, link_10Half } link;
+    uint16_t        mii_cr;
     uint16_t        mii_sr2;
 };
 static struct mcf5282_enet_struct enet_driver[NIFACES];
@@ -161,7 +156,7 @@ static rtems_isr
 mcf5282_fec_rx_interrupt_handler( rtems_vector_number v )
 {
     MCF5282_FEC_EIR = MCF5282_FEC_EIR_RXF;
-    MCF5282_FEC_EIMR &= ~MCF5282_FEC_EIMR_RXF;    
+    MCF5282_FEC_EIMR &= ~MCF5282_FEC_EIMR_RXF;
     enet_driver[0].rxInterrupts++;
     rtems_event_send(enet_driver[0].rxDaemonTid, RX_INTERRUPT_EVENT);
 }
@@ -170,7 +165,7 @@ static rtems_isr
 mcf5282_fec_tx_interrupt_handler( rtems_vector_number v )
 {
     MCF5282_FEC_EIR = MCF5282_FEC_EIR_TXF;
-    MCF5282_FEC_EIMR &= ~MCF5282_FEC_EIMR_TXF;    
+    MCF5282_FEC_EIMR &= ~MCF5282_FEC_EIMR_TXF;
     enet_driver[0].txInterrupts++;
     rtems_event_send(enet_driver[0].txDaemonTid, TX_INTERRUPT_EVENT);
 }
@@ -199,8 +194,7 @@ mcf5282_mii_interrupt_handler( rtems_vector_number v )
 static mcf5282BufferDescriptor_t *
 mcf5282_bd_allocate(unsigned int count)
 {
-    extern char __SRAMBASE[];
-    static mcf5282BufferDescriptor_t *bdp = (mcf5282BufferDescriptor_t *)(__SRAMBASE+16);
+    static mcf5282BufferDescriptor_t *bdp = __SRAMBASE.fec_descriptors;
     mcf5282BufferDescriptor_t *p = bdp;
 
     bdp += count;
@@ -275,14 +269,17 @@ mcf5282_fec_initialize_hardware(struct mcf5282_enet_struct *sc)
      *   Full duplex
      *   No loopback
      */
-    MCF5282_FEC_RCR = MCF5282_FEC_RCR_MAX_FL(MAX_MTU_SIZE) | 
+    MCF5282_FEC_RCR = MCF5282_FEC_RCR_MAX_FL(MAX_MTU_SIZE) |
                       MCF5282_FEC_RCR_MII_MODE;
 
     /*
      * Set up Transmit Control Register:
-     *   Full duplex
+     *   Full or half duplex
      *   No heartbeat
      */
+    if (sc->link == link_10Half)
+        MCF5282_FEC_TCR = 0;
+    else
     MCF5282_FEC_TCR = MCF5282_FEC_TCR_FDEN;
 
     /*
@@ -307,17 +304,38 @@ mcf5282_fec_initialize_hardware(struct mcf5282_enet_struct *sc)
      *  LED1 receive status, LED2 link status, LEDs stretched
      *  Advertise 100 Mb/s, full-duplex, IEEE-802.3
      *  Turn off auto-negotiate
-     *  Enable speed-change, duplex-change and link-status-change interrupts
-     *  Set 100/full and perhaps auto-negotiate
+     *  Clear status
      */
     setMII(1, 20, 0x24F2);
     setMII(1,  4, 0x0181);
-    setMII(1,  0, 0x2100);
+    setMII(1,  0, 0x0);
     rtems_task_wake_after(2);
     sc->mii_sr2 = getMII(1, 17);
+    switch (sc->link) {
+    case link_auto:
+        /*
+         * Enable speed-change, duplex-change and link-status-change interrupts
+         * Enable auto-negotiate (start at 100/FULL)
+         */
     setMII(1, 18, 0x0072);
-    if (!sc->force100Full)
         setMII(1, 0, 0x3100);
+        break;
+
+    case link_10Half:
+        /*
+         * Force 10/HALF
+         */
+        setMII(1, 0, 0x0);
+        break;
+
+    case link_100Full:
+        /*
+         * Force 100/FULL
+         */
+        setMII(1, 0, 0x2100);
+        break;
+    }
+    sc->mii_cr = getMII(1, 0);
 
     /*
      * Set up receive buffer descriptors
@@ -467,13 +485,9 @@ fec_rxDaemon (void *arg)
 #ifdef RTEMS_MCF5282_BSP_ENABLE_DATA_CACHE
             /*
              * Invalidate the cache.  The cache is so small that it's
-             * more efficient to just invalidate the whole thing unless
-             * the packet is very small.
+             * reasonable to simply invalidate the whole thing.
              */
-            if (len < 128)
-                rtems_cache_invalidate_multiple_data_lines(m->m_data, len);
-            else
-                rtems_cache_invalidate_entire_data();
+            rtems_cache_invalidate_entire_data();
 #endif
             m->m_len = m->m_pkthdr.len = len - sizeof(struct ether_header);
             eh = mtod(m, struct ether_header *);
@@ -526,9 +540,9 @@ fec_sendpacket(struct ifnet *ifp, struct mbuf *m)
      */
     nAdded = 0;
     firstTxBd = sc->txBdBase + sc->txBdHead;
-    
+
     while (m != NULL) {
-        /* 
+        /*
          * Wait for buffer descriptor to become available
          */
         if ((sc->txBdActiveCount + nAdded)  == sc->txBdCount) {
@@ -549,7 +563,7 @@ fec_sendpacket(struct ifnet *ifp, struct mbuf *m)
                 int level;
 
                 rtems_interrupt_disable(level);
-                MCF5282_FEC_EIMR |= MCF5282_FEC_EIMR_TXF;    
+                MCF5282_FEC_EIMR |= MCF5282_FEC_EIMR_TXF;
                 rtems_interrupt_enable(level);
                 sc->txRawWait++;
                 rtems_bsdnet_event_receive(TX_INTERRUPT_EVENT,
@@ -559,13 +573,13 @@ fec_sendpacket(struct ifnet *ifp, struct mbuf *m)
                 fec_retire_tx_bd(sc);
             }
         }
-    
+
         /*
          * Don't set the READY flag on the first fragment
          * until the whole packet has been readied.
          */
         status = nAdded ? MCF5282_FEC_TxBD_R : 0;
-    
+
         /*
          * The IP fragmentation routine in ip_output
          * can produce fragments with zero length.
@@ -644,9 +658,9 @@ fec_txDaemon(void *arg)
         /*
          * Wait for packet
          */
-        rtems_bsdnet_event_receive(START_TRANSMIT_EVENT, 
-                                    RTEMS_EVENT_ANY | RTEMS_WAIT, 
-                                    RTEMS_NO_TIMEOUT, 
+        rtems_bsdnet_event_receive(START_TRANSMIT_EVENT,
+                                    RTEMS_EVENT_ANY | RTEMS_WAIT,
+                                    RTEMS_NO_TIMEOUT,
                                     &events);
 
         /*
@@ -736,108 +750,122 @@ fec_stop(struct mcf5282_enet_struct *sc)
 static void
 enet_stats(struct mcf5282_enet_struct *sc)
 {
-    printf("  Rx Interrupts:%-10lu",   sc->rxInterrupts);
-    printf("Rx Packet Count:%-10lu",   MCF5282_FEC_RMON_R_PACKETS);
-    printf("   Rx Broadcast:%-10lu\n", MCF5282_FEC_RMON_R_BC_PKT);
-    printf("   Rx Multicast:%-10lu",   MCF5282_FEC_RMON_R_MC_PKT);
-    printf("CRC/Align error:%-10lu",   MCF5282_FEC_RMON_R_CRC_ALIGN);
-    printf("   Rx Undersize:%-10lu\n", MCF5282_FEC_RMON_R_UNDERSIZE);
-    printf("    Rx Oversize:%-10lu",   MCF5282_FEC_RMON_R_OVERSIZE);
-    printf("    Rx Fragment:%-10lu",   MCF5282_FEC_RMON_R_FRAG);
-    printf("      Rx Jabber:%-10lu\n", MCF5282_FEC_RMON_R_JAB);
-    printf("          Rx 64:%-10lu",   MCF5282_FEC_RMON_R_P64);
-    printf("      Rx 65-127:%-10lu",   MCF5282_FEC_RMON_R_P65T0127);
-    printf("     Rx 128-255:%-10lu\n", MCF5282_FEC_RMON_R_P128TO255);
-    printf("     Rx 256-511:%-10lu",   MCF5282_FEC_RMON_R_P256TO511);
-    printf("    Rx 511-1023:%-10lu",   MCF5282_FEC_RMON_R_P512TO1023);
-    printf("   Rx 1024-2047:%-10lu\n", MCF5282_FEC_RMON_R_P1024TO2047);
-    printf("      Rx >=2048:%-10lu",   MCF5282_FEC_RMON_R_GTE2048);
-    printf("      Rx Octets:%-10lu",   MCF5282_FEC_RMON_R_OCTETS);
-    printf("     Rx Dropped:%-10lu\n", MCF5282_FEC_IEEE_R_DROP);
-    printf("    Rx frame OK:%-10lu",   MCF5282_FEC_IEEE_R_FRAME_OK);
-    printf("   Rx CRC error:%-10lu",   MCF5282_FEC_IEEE_R_CRC);
-    printf(" Rx Align error:%-10lu\n", MCF5282_FEC_IEEE_R_ALIGN);
-    printf("  FIFO Overflow:%-10lu",   MCF5282_FEC_IEEE_R_MACERR);
-    printf("Rx Pause Frames:%-10lu",   MCF5282_FEC_IEEE_R_FDXFC);
-    printf("   Rx Octets OK:%-10lu\n", MCF5282_FEC_IEEE_R_OCTETS_OK);
-    printf("  Tx Interrupts:%-10lu",   sc->txInterrupts);
-    printf("Tx Output Waits:%-10lu",   sc->txRawWait);
-    printf("Tx mbuf realign:%-10lu\n", sc->txRealign);
-    printf("Tx realign drop:%-10lu",   sc->txRealignDrop);
-    printf(" Tx Unaccounted:%-10lu",   MCF5282_FEC_RMON_T_DROP);
-    printf("Tx Packet Count:%-10lu\n", MCF5282_FEC_RMON_T_PACKETS);
-    printf("   Tx Broadcast:%-10lu",   MCF5282_FEC_RMON_T_BC_PKT);
-    printf("   Tx Multicast:%-10lu",   MCF5282_FEC_RMON_T_MC_PKT);
-    printf("CRC/Align error:%-10lu\n", MCF5282_FEC_RMON_T_CRC_ALIGN);
-    printf("   Tx Undersize:%-10lu",   MCF5282_FEC_RMON_T_UNDERSIZE);
-    printf("    Tx Oversize:%-10lu",   MCF5282_FEC_RMON_T_OVERSIZE);
-    printf("    Tx Fragment:%-10lu\n", MCF5282_FEC_RMON_T_FRAG);
-    printf("      Tx Jabber:%-10lu",   MCF5282_FEC_RMON_T_JAB);
-    printf("  Tx Collisions:%-10lu",   MCF5282_FEC_RMON_T_COL);
-    printf("          Tx 64:%-10lu\n", MCF5282_FEC_RMON_T_P64);
-    printf("      Tx 65-127:%-10lu",   MCF5282_FEC_RMON_T_P65TO127);
-    printf("     Tx 128-255:%-10lu",   MCF5282_FEC_RMON_T_P128TO255);
-    printf("     Tx 256-511:%-10lu\n", MCF5282_FEC_RMON_T_P256TO511);
-    printf("    Tx 511-1023:%-10lu",   MCF5282_FEC_RMON_T_P512TO1023);
-    printf("   Tx 1024-2047:%-10lu",   MCF5282_FEC_RMON_T_P1024TO2047);
-    printf("      Tx >=2048:%-10lu\n", MCF5282_FEC_RMON_T_P_GTE2048);
-    printf("      Tx Octets:%-10lu",   MCF5282_FEC_RMON_T_OCTETS);
-    printf("     Tx Dropped:%-10lu",   MCF5282_FEC_IEEE_T_DROP);
-    printf("    Tx Frame OK:%-10lu\n", MCF5282_FEC_IEEE_T_FRAME_OK);
-    printf(" Tx 1 Collision:%-10lu",   MCF5282_FEC_IEEE_T_1COL);
-    printf("Tx >1 Collision:%-10lu",   MCF5282_FEC_IEEE_T_MCOL);
-    printf("    Tx Deferred:%-10lu\n", MCF5282_FEC_IEEE_T_DEF);
-    printf(" Late Collision:%-10lu",   MCF5282_FEC_IEEE_T_LCOL);
-    printf(" Excessive Coll:%-10lu",   MCF5282_FEC_IEEE_T_EXCOL);
-    printf("  FIFO Underrun:%-10lu\n", MCF5282_FEC_IEEE_T_MACERR);
-    printf("  Carrier Error:%-10lu",   MCF5282_FEC_IEEE_T_CSERR);
-    printf("   Tx SQE Error:%-10lu",   MCF5282_FEC_IEEE_T_SQE);
-    printf("Tx Pause Frames:%-10lu\n", MCF5282_FEC_IEEE_T_FDXFC);
-    printf("   Tx Octets OK:%-10lu",   MCF5282_FEC_IEEE_T_OCTETS_OK);
-    printf(" MII interrupts:%-10lu\n", sc->miiInterrupts);
-    if ((sc->mii_sr2 & 0x400) == 0) {
-        printf("LINK DOWN!\n");
-    }
-    else {
-        printf("Link speed %d Mb/s, %s-duplex.\n",
-                                    sc->mii_sr2  & 0x4000 ? 100 : 10,
-                                    sc->mii_sr2 & 0x200 ? "full" : "half");
-    }
-    printf(" EIR:%8.8lx  ",  MCF5282_FEC_EIR);
-    printf("EIMR:%8.8lx  ",  MCF5282_FEC_EIMR);
-    printf("RDAR:%8.8lx  ",  MCF5282_FEC_RDAR);
-    printf("TDAR:%8.8lx\n",  MCF5282_FEC_TDAR);
-    printf(" ECR:%8.8lx  ",  MCF5282_FEC_ECR);
-    printf(" RCR:%8.8lx  ",  MCF5282_FEC_RCR);
-    printf(" TCR:%8.8lx\n",  MCF5282_FEC_TCR);
-    printf("FRBR:%8.8lx  ",  MCF5282_FEC_FRBR);
-    printf("FRSR:%8.8lx\n",  MCF5282_FEC_FRSR);
-    if (sc->txBdActiveCount != 0) {
-        int i, n;
-        /*
-         * Yes, there are races here with adding and retiring descriptors,
-         * but this diagnostic is more for when things have backed up.
-         */
-        printf("Transmit Buffer Descriptors (Tail %d, Head %d, Unretired %d):\n",
-                                                    sc->txBdTail,
-                                                    sc->txBdHead,
-                                                    sc->txBdActiveCount);
-        i = sc->txBdTail;
-        for (n = 0 ; n < sc->txBdCount ; n++) {
-            if ((sc->txBdBase[i].status & MCF5282_FEC_TxBD_R) != 0)
-                printf("  %3d: status:%4.4x  length:%-4d  buffer:%p\n",
-                                                    i,
-                                                    sc->txBdBase[i].status,
-                                                    sc->txBdBase[i].length,
-                                                    sc->txBdBase[i].buffer);
-            if (++i == sc->txBdCount)
-                i = 0;
-        }
-    }
+  printf("  Rx Interrupts:%-10lu",   sc->rxInterrupts);
+  printf("Rx Packet Count:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_PACKETS);
+  printf("   Rx Broadcast:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_R_BC_PKT);
+  printf("   Rx Multicast:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_MC_PKT);
+  printf("CRC/Align error:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_CRC_ALIGN);
+  printf("   Rx Undersize:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_R_UNDERSIZE);
+  printf("    Rx Oversize:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_OVERSIZE);
+  printf("    Rx Fragment:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_FRAG);
+  printf("      Rx Jabber:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_R_JAB);
+  printf("          Rx 64:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_P64);
+  printf("      Rx 65-127:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_P65T0127);
+  printf("     Rx 128-255:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_R_P128TO255);
+  printf("     Rx 256-511:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_P256TO511);
+  printf("    Rx 511-1023:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_P512TO1023);
+  printf("   Rx 1024-2047:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_R_P1024TO2047);
+  printf("      Rx >=2048:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_GTE2048);
+  printf("      Rx Octets:%-10lu",   (uint32_t) MCF5282_FEC_RMON_R_OCTETS);
+  printf("     Rx Dropped:%-10lu\n", (uint32_t) MCF5282_FEC_IEEE_R_DROP);
+  printf("    Rx frame OK:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_R_FRAME_OK);
+  printf("   Rx CRC error:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_R_CRC);
+  printf(" Rx Align error:%-10lu\n", (uint32_t) MCF5282_FEC_IEEE_R_ALIGN);
+  printf("  FIFO Overflow:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_R_MACERR);
+  printf("Rx Pause Frames:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_R_FDXFC);
+  printf("   Rx Octets OK:%-10lu\n", (uint32_t) MCF5282_FEC_IEEE_R_OCTETS_OK);
+  printf("  Tx Interrupts:%-10lu",   sc->txInterrupts);
+  printf("Tx Output Waits:%-10lu",   sc->txRawWait);
+  printf("Tx mbuf realign:%-10lu\n", sc->txRealign);
+  printf("Tx realign drop:%-10lu",   sc->txRealignDrop);
+  printf(" Tx Unaccounted:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_DROP);
+  printf("Tx Packet Count:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_T_PACKETS);
+  printf("   Tx Broadcast:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_BC_PKT);
+  printf("   Tx Multicast:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_MC_PKT);
+  printf("CRC/Align error:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_T_CRC_ALIGN);
+  printf("   Tx Undersize:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_UNDERSIZE);
+  printf("    Tx Oversize:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_OVERSIZE);
+  printf("    Tx Fragment:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_T_FRAG);
+  printf("      Tx Jabber:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_JAB);
+  printf("  Tx Collisions:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_COL);
+  printf("          Tx 64:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_T_P64);
+  printf("      Tx 65-127:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_P65TO127);
+  printf("     Tx 128-255:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_P128TO255);
+  printf("     Tx 256-511:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_T_P256TO511);
+  printf("    Tx 511-1023:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_P512TO1023);
+  printf("   Tx 1024-2047:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_P1024TO2047);
+  printf("      Tx >=2048:%-10lu\n", (uint32_t) MCF5282_FEC_RMON_T_P_GTE2048);
+  printf("      Tx Octets:%-10lu",   (uint32_t) MCF5282_FEC_RMON_T_OCTETS);
+  printf("     Tx Dropped:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_T_DROP);
+  printf("    Tx Frame OK:%-10lu\n", (uint32_t) MCF5282_FEC_IEEE_T_FRAME_OK);
+  printf(" Tx 1 Collision:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_T_1COL);
+  printf("Tx >1 Collision:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_T_MCOL);
+  printf("    Tx Deferred:%-10lu\n", (uint32_t) MCF5282_FEC_IEEE_T_DEF);
+  printf(" Late Collision:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_T_LCOL);
+  printf(" Excessive Coll:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_T_EXCOL);
+  printf("  FIFO Underrun:%-10lu\n", (uint32_t) MCF5282_FEC_IEEE_T_MACERR);
+  printf("  Carrier Error:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_T_CSERR);
+  printf("   Tx SQE Error:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_T_SQE);
+  printf("Tx Pause Frames:%-10lu\n", (uint32_t) MCF5282_FEC_IEEE_T_FDXFC);
+  printf("   Tx Octets OK:%-10lu",   (uint32_t) MCF5282_FEC_IEEE_T_OCTETS_OK);
+  printf(" MII interrupts:%-10lu\n", sc->miiInterrupts);
+  if ((sc->mii_sr2 & 0x400) == 0) {
+      printf("LINK DOWN!\n");
+  }
+  else {
+      int speed;
+      int full;
+      int fixed;
+      if (sc->mii_cr & 0x1000) {
+	  fixed = 0;
+	  speed = sc->mii_sr2 & 0x4000 ? 100 : 10;
+	  full = sc->mii_sr2 & 0x200 ? 1 : 0;
+      }
+      else {
+	  fixed = 1;
+	  speed = sc->mii_cr & 0x2000 ? 100 : 10;
+	  full = sc->mii_cr & 0x100 ? 1 : 0;
+      }
+      printf("Link %s %d Mb/s, %s-duplex.\n",
+					  fixed ? "fixed" : "auto-negotiate",
+					  speed,
+					  full ? "full" : "half");
+  }
+  printf(" EIR:%8.8lx  ",  (uint32_t) MCF5282_FEC_EIR);
+  printf("EIMR:%8.8lx  ",  (uint32_t) MCF5282_FEC_EIMR);
+  printf("RDAR:%8.8lx  ",  (uint32_t) MCF5282_FEC_RDAR);
+  printf("TDAR:%8.8lx\n",  (uint32_t) MCF5282_FEC_TDAR);
+  printf(" ECR:%8.8lx  ",  (uint32_t) MCF5282_FEC_ECR);
+  printf(" RCR:%8.8lx  ",  (uint32_t) MCF5282_FEC_RCR);
+  printf(" TCR:%8.8lx\n",  (uint32_t) MCF5282_FEC_TCR);
+  printf("FRBR:%8.8lx  ",  (uint32_t) MCF5282_FEC_FRBR);
+  printf("FRSR:%8.8lx\n",  (uint32_t) MCF5282_FEC_FRSR);
+  if (sc->txBdActiveCount != 0) {
+      int i, n;
+      /*
+       * Yes, there are races here with adding and retiring descriptors,
+       * but this diagnostic is more for when things have backed up.
+       */
+      printf("Transmit Buffer Descriptors (Tail %d, Head %d, Unretired %d):\n",
+						  sc->txBdTail,
+						  sc->txBdHead,
+						  sc->txBdActiveCount);
+      i = sc->txBdTail;
+      for (n = 0 ; n < sc->txBdCount ; n++) {
+	  if ((sc->txBdBase[i].status & MCF5282_FEC_TxBD_R) != 0)
+	      printf("  %3d: status:%4.4x  length:%-4d  buffer:%p\n",
+						  i,
+						  sc->txBdBase[i].status,
+						  sc->txBdBase[i].length,
+						  sc->txBdBase[i].buffer);
+	  if (++i == sc->txBdCount)
+	      i = 0;
+      }
+  }
 }
 
 static int
-fec_ioctl(struct ifnet *ifp, int command, caddr_t data)
+fec_ioctl(struct ifnet *ifp, ioctl_command_t command, caddr_t data)
 {
     struct mcf5282_enet_struct *sc = ifp->if_softc;
     int error = 0;
@@ -890,7 +918,7 @@ rtems_fec_driver_attach(struct rtems_bsdnet_ifconfig *config, int attaching )
     int mtu;
     int unitNumber;
     char *unitName;
-    unsigned char *hwaddr;
+    const unsigned char *hwaddr;
     const char *env;
 
     /*
@@ -967,7 +995,12 @@ rtems_fec_driver_attach(struct rtems_bsdnet_ifconfig *config, int attaching )
      */
     if (((env = bsp_getbenv("IPADDR0_100FULL")) != NULL)
      && ((*env == 'y') || (*env == 'Y')))
-        sc->force100Full = 1;
+        sc->link = link_100Full;
+    else if (((env = bsp_getbenv("IPADDR0_10HALF")) != NULL)
+     && ((*env == 'y') || (*env == 'Y')))
+        sc->link = link_10Half;
+    else
+        sc->link = link_auto;
 
     /*
      * Attach the interface
