@@ -31,7 +31,7 @@
 
 scmv91111_configuration_t leon_scmv91111_configuration = {
   SMC91111_BASE_ADDR, /* base address */
-  SMC91111_BASE_IRQ,  /* vector number to IRQ funcs (on LEON IRQ is used) */
+  SMC91111_BASE_IRQ,  /* IRQ number to IRQ funcs */
   SMC91111_BASE_PIO,  /* PIO */
   100,                /* 100b */
   1,                  /* fulldx */
@@ -55,7 +55,7 @@ int rtems_smc91111_driver_attach_leon2(struct rtems_bsdnet_ifconfig *config)
   *((volatile unsigned int *)0x80000000) |= 0x10f80000;
   *((volatile unsigned int *)0x800000A8) |=
     (0xe0 | leon_scmv91111_configuration.pio)
-      << (8 * ((leon_scmv91111_configuration.vector & 0x0f) - 4));
+      << (8 * (leon_scmv91111_configuration.irq - 4));
 
   return _rtems_smc91111_driver_attach(config,&leon_scmv91111_configuration);
 
