@@ -824,10 +824,12 @@ sendpacket (struct ifnet *ifp, struct mbuf *m)
 
     if (len <= GRETH_MAXBUF_LEN) {
             if (dp->tx_ptr < dp->txbufs-1) {
-                    dp->txdesc[dp->tx_ptr].ctrl = GRETH_TXD_ENABLE | len;
+                    dp->txdesc[dp->tx_ptr].ctrl = GRETH_TXD_IRQ |
+                                                  GRETH_TXD_ENABLE | len;
             } else {
-                    dp->txdesc[dp->tx_ptr].ctrl = 
-                            GRETH_TXD_WRAP | GRETH_TXD_ENABLE | len;
+                    dp->txdesc[dp->tx_ptr].ctrl = GRETH_TXD_IRQ |
+                                                  GRETH_TXD_WRAP |
+                                                  GRETH_TXD_ENABLE | len;
             }
             dp->tx_ptr = (dp->tx_ptr + 1) % dp->txbufs;
             rtems_interrupt_disable(level);
