@@ -648,6 +648,12 @@ int grspw_close(void *d)
 	}
 	grspw_hw_stop(priv);
 
+	/* Free descriptor table memory if allocated using malloc() */
+	if (priv->bd_mem_alloced) {
+		free((void *)priv->bd_mem_alloced);
+		priv->bd_mem_alloced = 0;
+	}
+
 	/* Mark not open */
 	priv->open = 0;
 	rtems_semaphore_release(grspw_sem);
@@ -2735,7 +2741,8 @@ STATIC void grspw_isr(void *data)
 		if (stat & GRSPW_STS_WE)
 			priv->stats.err_wsync++;
 
-		if ((priv->dis_link_on_err >> 16) & stat) {
+		if (((priv->dis_link_on_err >> 16) & stat) &&
+		    (REG_READ(&priv->regs->ctrl) & GRSPW_CTRL_IE)) {
 			/* Disable the link, no more transfers are expected
 			 * on any DMA channel.
 			 */
@@ -2902,6 +2909,20 @@ void grspw_initialize_user(void *(*devfound)(int), void (*devremove)(int,void*))
 	}
 }
 
+/* Get a value at least 6.4us in number of clock cycles */
+static unsigned int grspw1_calc_timer64(int freq_khz)
+{
+	unsigned int timer64 = (freq_khz * 64 + 9999) / 10000;
+	return timer64 & 0xfff;
+}
+
+/* Get a value at least 850ns in number of clock cycles - 3 */
+static unsigned int grspw1_calc_discon(int freq_khz)
+{
+	unsigned int discon = ((freq_khz * 85 + 99999) / 100000) - 3;
+	return discon & 0x3ff;
+}
+
 /******************* Driver manager interface ***********************/
 
 /* Driver prototypes */
@@ -3003,9 +3024,18 @@ static int grspw2_init3(struct drvmgr_dev *dev)
 		priv->hwsup.strip_adr = 1; /* All GRSPW2 can strip Address */
 		priv->hwsup.strip_pid = 1; /* All GRSPW2 can strip PID */
 	} else {
+		unsigned int apb_hz, apb_khz;
+
 		/* Autodetect GRSPW1 features? */
 		priv->hwsup.strip_adr = 0;
 		priv->hwsup.strip_pid = 0;
+
+		drvmgr_freq_get(dev, DEV_APB_SLV, &apb_hz);
+		apb_khz = apb_hz / 1000;
+
+		REG_WRITE(&priv->regs->timer,
+			((grspw1_calc_discon(apb_khz) & 0x3FF) << 12) |
+			(grspw1_calc_timer64(apb_khz) & 0xFFF));
 	}
 
 	/* Probe width of SpaceWire Interrupt ISR timers. All have the same
