@@ -6,7 +6,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: set_tim.c,v 1.1 2007/04/17 20:32:13 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -25,7 +25,7 @@
  */
 
 ER set_tim(
-  SYSTIME *pk_tim
+  SYSTIME *pk_tim __attribute__((unused))
 )
 {
 #if 0
