@@ -10,20 +10,19 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: __sbrk.c,v 1.4 2003/09/04 18:54:13 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <rtems.h>
-#if !defined(RTEMS_UNIX)
+#if defined(RTEMS_NEWLIB) && !defined(HAVE___SBRK)
 
 #include <errno.h>
 
 void * __sbrk(
-  int incr
+  int incr __attribute__((unused))
 )
 {
   errno = EINVAL;
