@@ -1,14 +1,14 @@
 /*
  *  chdir() - POSIX 1003.1b - 5.2.1 - Change Current Working Directory
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2010.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: chdir.c,v 1.11 2004/04/18 06:05:34 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -30,19 +30,20 @@ int chdir(
   rtems_filesystem_location_info_t  loc;
   int                               result;
 
+  if ( !pathname )
+    rtems_set_errno_and_return_minus_one( EFAULT );
+
   /*
    *  Get the node where we wish to go.
    */
-
   result = rtems_filesystem_evaluate_path(
-    pathname, RTEMS_LIBIO_PERMS_SEARCH, &loc, TRUE );
+    pathname, strlen( pathname ), RTEMS_LIBIO_PERMS_SEARCH, &loc, true );
   if ( result != 0 )
      return -1;
 
   /*
    * Verify you can change directory into this node.
    */
-
   if ( !loc.ops->node_type_h ) {
     rtems_filesystem_freenode( &loc );
     rtems_set_errno_and_return_minus_one( ENOTSUP );
