@@ -8,7 +8,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  @(#) $Id: msdos_handlers_dir.c,v 1.3 2004/04/17 08:34:40 ralf Exp $
+ *  @(#) $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -18,7 +18,7 @@
 #include <rtems/libio.h>
 #include "msdos.h"
 
-rtems_filesystem_file_handlers_r msdos_dir_handlers = {
+const rtems_filesystem_file_handlers_r msdos_dir_handlers = {
     msdos_dir_open,
     msdos_dir_close,
     msdos_dir_read,
@@ -26,7 +26,7 @@ rtems_filesystem_file_handlers_r msdos_dir_handlers = {
     NULL,             /* msdos_dir_ioctl */
     msdos_dir_lseek,
     msdos_dir_stat,
-    NULL,
+    msdos_dir_chmod,
     NULL,             /* msdos_dir_ftruncate */
     NULL,
     msdos_dir_sync,
