@@ -10,7 +10,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: imfs_getchild.c,v 1.8 2004/04/17 08:34:41 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -22,17 +22,17 @@
 #include <string.h>
 #include "imfs.h"
 
-static char dotname[2] = ".";
-static char dotdotname[3] = "..";
+static const char dotname[2] = ".";
+static const char dotdotname[3] = "..";
 
 IMFS_jnode_t *IMFS_find_match_in_dir(
   IMFS_jnode_t *directory,
   char         *name
 )
 {
-  Chain_Node        *the_node;
-  Chain_Control     *the_chain;
-  IMFS_jnode_t      *the_jnode;
+  rtems_chain_node    *the_node;
+  rtems_chain_control *the_chain;
+  IMFS_jnode_t        *the_jnode;
 
   /*
    *  Check for fatal errors.  A NULL directory show a problem in the
@@ -60,7 +60,7 @@ IMFS_jnode_t *IMFS_find_match_in_dir(
   the_chain = &directory->info.directory.Entries;
 
   for ( the_node = the_chain->first;
-        !_Chain_Is_tail( the_chain, the_node );
+        !rtems_chain_is_tail( the_chain, the_node );
         the_node = the_node->next ) {
 
     the_jnode = (IMFS_jnode_t *) the_node;
