@@ -8,7 +8,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: imfs_init.c,v 1.13 2005/02/08 17:12:54 ericn Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -33,7 +33,7 @@
  *  IMFS file system operations table
  */
 
-rtems_filesystem_operations_table  IMFS_ops = {
+const rtems_filesystem_operations_table  IMFS_ops = {
   IMFS_eval_path,
   IMFS_evaluate_for_make,
   IMFS_link,
@@ -49,7 +49,9 @@ rtems_filesystem_operations_table  IMFS_ops = {
   IMFS_utime,
   IMFS_evaluate_link,
   IMFS_symlink,
-  IMFS_readlink
+  IMFS_readlink,
+  IMFS_rename,
+  NULL
 };
 
 /*
@@ -57,7 +59,8 @@ rtems_filesystem_operations_table  IMFS_ops = {
  */
 
 int IMFS_initialize(
-  rtems_filesystem_mount_table_entry_t *temp_mt_entry
+  rtems_filesystem_mount_table_entry_t *temp_mt_entry,
+  const void                           *data
 )
 {
    return IMFS_initialize_support(
