@@ -115,6 +115,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
 #include <time.h>
 
 #define SPRINTF(x) sprintf x
@@ -300,11 +303,12 @@ p_cdname(const u_char *cp, const u_char *msg, FILE *file) {
    length supplied).  */
 
 const u_char *
-p_fqnname(cp, msg, msglen, name, namelen)
-	const u_char *cp, *msg;
-	int msglen;
-	char *name;
-	int namelen;
+p_fqnname(
+	const u_char *cp, 
+	const u_char *msg,
+	int msglen,
+	char *name,
+	int namelen)
 {
 	int n, newlen;
 
@@ -340,32 +344,32 @@ p_fqname(const u_char *cp, const u_char *msg, FILE *file) {
  * C_ANY, but you can't have any records of that class in the database.)
  */
 const struct res_sym __p_class_syms[] = {
-	{C_IN,		"IN"},
-	{C_CHAOS,	"CHAOS"},
-	{C_HS,		"HS"},
-	{C_HS,		"HESIOD"},
-	{C_ANY,		"ANY"},
-	{C_NONE,	"NONE"},
-	{C_IN, 		(char *)0}
+	{C_IN,		"IN", 		NULL},
+	{C_CHAOS,	"CHAOS", 	NULL},
+	{C_HS,		"HS", 		NULL},
+	{C_HS,		"HESIOD", 	NULL},
+	{C_ANY,		"ANY", 		NULL},
+	{C_NONE,	"NONE",		NULL},
+	{C_IN, 		(char *)0,	NULL}
 };
 
 /*
  * Names of message sections.
  */
 const struct res_sym __p_default_section_syms[] = {
-	{ns_s_qd,	"QUERY"},
-	{ns_s_an,	"ANSWER"},
-	{ns_s_ns,	"AUTHORITY"},
-	{ns_s_ar,	"ADDITIONAL"},
-	{0,             (char *)0}
+	{ns_s_qd,	"QUERY",	NULL},
+	{ns_s_an,	"ANSWER", 	NULL},
+	{ns_s_ns,	"AUTHORITY",	NULL},
+	{ns_s_ar,	"ADDITIONAL",	NULL},
+	{0,             (char *)0,	NULL}
 };
 
 const struct res_sym __p_update_section_syms[] = {
-	{S_ZONE,	"ZONE"},
-	{S_PREREQ,	"PREREQUISITE"},
-	{S_UPDATE,	"UPDATE"},
-	{S_ADDT,	"ADDITIONAL"},
-	{0,             (char *)0}
+	{S_ZONE,	"ZONE",		NULL},
+	{S_PREREQ,	"PREREQUISITE",	NULL},
+	{S_UPDATE,	"UPDATE",	NULL},
+	{S_ADDT,	"ADDITIONAL",	NULL},
+	{0,             (char *)0,	NULL}
 };
 
 /*
@@ -549,8 +553,8 @@ static uint32_t poweroften[10] = {1, 10, 100, 1000, 10000, 100000,
 
 /* takes an XeY precision/size value, returns a string representation. */
 static const char *
-precsize_ntoa(prec)
-	u_int8_t prec;
+precsize_ntoa(
+	u_int8_t prec)
 {
 	static char retbuf[sizeof "90000000.00"];
 	unsigned long val;
@@ -567,8 +571,8 @@ precsize_ntoa(prec)
 
 /* converts ascii size/precision X * 10**Y(cm) to 0xXY.  moves pointer. */
 static u_int8_t
-precsize_aton(strptr)
-	const char **strptr;
+precsize_aton(
+	const char **strptr)
 {
 	unsigned int mval = 0, cmval = 0;
 	u_int8_t retval = 0;
@@ -578,14 +582,14 @@ precsize_aton(strptr)
 
 	cp = *strptr;
 
-	while (isdigit((int)*cp))
+	while (isdigit((unsigned char)*cp))
 		mval = mval * 10 + (*cp++ - '0');
 
 	if (*cp == '.') {		/* centimeters */
 		cp++;
-		if (isdigit((int)*cp)) {
+		if (isdigit((unsigned char)*cp)) {
 			cmval = (*cp++ - '0') * 10;
-			if (isdigit((int)*cp)) {
+			if (isdigit((unsigned char)*cp)) {
 				cmval += (*cp++ - '0');
 			}
 		}
@@ -609,9 +613,9 @@ precsize_aton(strptr)
 
 /* converts ascii lat/lon to unsigned encoded 32-bit number.  moves pointer. */
 static u_int32_t
-latlon2ul(latlonstrptr,which)
-	char **latlonstrptr;
-	int *which;
+latlon2ul(
+	char **latlonstrptr,
+	int *which )
 {
 	char *cp;
 	u_int32_t retval;
@@ -619,44 +623,44 @@ latlon2ul(latlonstrptr,which)
 
 	cp = *latlonstrptr;
 
-	while (isdigit((int)*cp))
+	while (isdigit((unsigned char)*cp))
 		deg = deg * 10 + (*cp++ - '0');
 
-	while (isspace((int)*cp))
+	while (isspace((unsigned char)*cp))
 		cp++;
 
-	if (!(isdigit((int)*cp)))
+	if (!(isdigit((unsigned char)*cp)))
 		goto fndhemi;
 
-	while (isdigit((int)*cp))
+	while (isdigit((unsigned char)*cp))
 		min = min * 10 + (*cp++ - '0');
 
-	while (isspace((int)*cp))
+	while (isspace((unsigned char)*cp))
 		cp++;
 
-	if (!(isdigit((int)*cp)))
+	if (!(isdigit((unsigned char)*cp)))
 		goto fndhemi;
 
-	while (isdigit((int)*cp))
+	while (isdigit((unsigned char)*cp))
 		secs = secs * 10 + (*cp++ - '0');
 
 	if (*cp == '.') {		/* decimal seconds */
 		cp++;
-		if (isdigit((int)*cp)) {
+		if (isdigit((unsigned char)*cp)) {
 			secsfrac = (*cp++ - '0') * 100;
-			if (isdigit((int)*cp)) {
+			if (isdigit((unsigned char)*cp)) {
 				secsfrac += (*cp++ - '0') * 10;
-				if (isdigit((int)*cp)) {
+				if (isdigit((unsigned char)*cp)) {
 					secsfrac += (*cp++ - '0');
 				}
 			}
 		}
 	}
 
-	while (!isspace((int)*cp))	/* if any trailing garbage */
+	while (!isspace((unsigned char)*cp))	/* if any trailing garbage */
 		cp++;
 
-	while (isspace((int)*cp))
+	while (isspace((unsigned char)*cp))
 		cp++;
 
  fndhemi:
@@ -694,10 +698,10 @@ latlon2ul(latlonstrptr,which)
 
 	cp++;			/* skip the hemisphere */
 
-	while (!isspace((int)*cp))	/* if any trailing garbage */
+	while (!isspace((unsigned char)*cp))	/* if any trailing garbage */
 		cp++;
 
-	while (isspace((int)*cp))	/* move to next field */
+	while (isspace((unsigned char)*cp))	/* move to next field */
 		cp++;
 
 	*latlonstrptr = cp;
@@ -708,9 +712,9 @@ latlon2ul(latlonstrptr,which)
 /* converts a zone file representation in a string to an RDATA on-the-wire
  * representation. */
 int
-loc_aton(ascii, binary)
-	const char *ascii;
-	u_char *binary;
+loc_aton(
+	const char *ascii,
+	u_char *binary)
 {
 	const char *cp, *maxcp;
 	u_char *bcp;
@@ -726,9 +730,9 @@ loc_aton(ascii, binary)
 	cp = ascii;
 	maxcp = cp + strlen(ascii);
 
-	lltemp1 = latlon2ul(&cp, &which1);
+	lltemp1 = latlon2ul((char **)&cp, &which1);
 
-	lltemp2 = latlon2ul(&cp, &which2);
+	lltemp2 = latlon2ul((char **)&cp, &which2);
 
 	switch (which1 + which2) {
 	case 3:			/* 1 + 2, the only valid combination */
@@ -755,14 +759,14 @@ loc_aton(ascii, binary)
 	if (*cp == '+')
 		cp++;
 
-	while (isdigit((int)*cp))
+	while (isdigit((unsigned char)*cp))
 		altmeters = altmeters * 10 + (*cp++ - '0');
 
 	if (*cp == '.') {		/* decimal meters */
 		cp++;
-		if (isdigit((int)*cp)) {
+		if (isdigit((unsigned char)*cp)) {
 			altfrac = (*cp++ - '0') * 10;
-			if (isdigit((int)*cp)) {
+			if (isdigit((unsigned char)*cp)) {
 				altfrac += (*cp++ - '0');
 			}
 		}
@@ -770,10 +774,10 @@ loc_aton(ascii, binary)
 
 	alt = (10000000 + (altsign * (altmeters * 100 + altfrac)));
 
-	while (!isspace((int)*cp) && (cp < maxcp)) /* if trailing garbage or m */
+	while (!isspace((unsigned char)*cp) && (cp < maxcp)) /* if trailing garbage or m */
 		cp++;
 
-	while (isspace((int)*cp) && (cp < maxcp))
+	while (isspace((unsigned char)*cp) && (cp < maxcp))
 		cp++;
 
 	if (cp >= maxcp)
@@ -781,10 +785,10 @@ loc_aton(ascii, binary)
 
 	siz = precsize_aton(&cp);
 	
-	while (!isspace((int)*cp) && (cp < maxcp))	/* if trailing garbage or m */
+	while (!isspace((unsigned char)*cp) && (cp < maxcp))	/* if trailing garbage or m */
 		cp++;
 
-	while (isspace((int)*cp) && (cp < maxcp))
+	while (isspace((unsigned char)*cp) && (cp < maxcp))
 		cp++;
 
 	if (cp >= maxcp)
@@ -792,10 +796,10 @@ loc_aton(ascii, binary)
 
 	hp = precsize_aton(&cp);
 
-	while (!isspace((int)*cp) && (cp < maxcp))	/* if trailing garbage or m */
+	while (!isspace((unsigned char)*cp) && (cp < maxcp))	/* if trailing garbage or m */
 		cp++;
 
-	while (isspace((int)*cp) && (cp < maxcp))
+	while (isspace((unsigned char)*cp) && (cp < maxcp))
 		cp++;
 
 	if (cp >= maxcp)
@@ -819,9 +823,9 @@ loc_aton(ascii, binary)
 
 /* takes an on-the-wire LOC RR and formats it in a human readable format. */
 const char *
-loc_ntoa(binary, ascii)
-	const u_char *binary;
-	char *ascii;
+loc_ntoa(
+	const u_char *binary,
+	char *ascii )
 {
 	static char *error = "?";
 	const u_char *cp = binary;
