@@ -10,10 +10,6 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
@@ -31,9 +27,13 @@
  * SUCH DAMAGE.
  *
  *	@(#)tcp_output.c	8.4 (Berkeley) 5/24/95
- *	$Id: tcp_output.c,v 1.2 2007/05/10 05:12:54 ralf Exp $
+ *	$Id$
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "opt_tcpdebug.h"
 
 #include <sys/param.h>
@@ -44,7 +44,7 @@
 #include <sys/protosw.h>
 #include <sys/socket.h>
 #include <sys/socketvar.h>
-#include <sys/errno.h>
+#include <errno.h>
 
 #include <net/route.h>
 
@@ -73,8 +73,8 @@ extern struct mbuf *m_copypack();
  * Tcp output routine: figure out what should be sent and send it.
  */
 int
-tcp_output(tp)
-	register struct tcpcb *tp;
+tcp_output(
+	register struct tcpcb *tp)
 {
 	register struct socket *so = tp->t_inpcb->inp_socket;
 	register long len, win;
@@ -737,8 +737,8 @@ out:
 }
 
 void
-tcp_setpersist(tp)
-	register struct tcpcb *tp;
+tcp_setpersist(
+	register struct tcpcb *tp)
 {
 	register int t = ((tp->t_srtt >> 2) + tp->t_rttvar) >> 1;
 
