@@ -1,5 +1,12 @@
 /*
- *  $Id: clocksettime.c,v 1.7 2007/04/13 03:19:11 ralf Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -16,6 +23,8 @@
 
 #include <rtems/seterr.h>
 
+#include "posixtime.h"
+
 /*PAGE
  *
  *  14.2.1 Clocks, P1003.1b-1993, p. 263
@@ -29,31 +38,24 @@ int clock_settime(
   if ( !tp )
     rtems_set_errno_and_return_minus_one( EINVAL );
 
-  switch ( clock_id ) {
-
-    case CLOCK_REALTIME:
-      if ( tp->tv_sec < TOD_SECONDS_1970_THROUGH_1988 )
-        rtems_set_errno_and_return_minus_one( EINVAL );
-
-      _Thread_Disable_dispatch();
-        _TOD_Set( tp );
-      _Thread_Enable_dispatch();
-      break;
-
-#ifdef _POSIX_CPUTIME
-    case CLOCK_PROCESS_CPUTIME:
-      return POSIX_NOT_IMPLEMENTED();
-      break;
-#endif
-
-#ifdef _POSIX_THREAD_CPUTIME
-    case CLOCK_THREAD_CPUTIME:
-      return POSIX_NOT_IMPLEMENTED();
-      break;
-#endif
-    default:
+  if ( clock_id == CLOCK_REALTIME ) {
+    if ( tp->tv_sec < TOD_SECONDS_1970_THROUGH_1988 )
       rtems_set_errno_and_return_minus_one( EINVAL );
 
+    _Thread_Disable_dispatch();
+      _TOD_Set( tp );
+    _Thread_Enable_dispatch();
   }
+#ifdef _POSIX_CPUTIME
+  else if ( clock_id == CLOCK_PROCESS_CPUTIME_ID )
+    rtems_set_errno_and_return_minus_one( ENOSYS );
+#endif
+#ifdef _POSIX_THREAD_CPUTIME
+  else if ( clock_id == CLOCK_THREAD_CPUTIME_ID )
+    rtems_set_errno_and_return_minus_one( ENOSYS );
+#endif
+  else
+    rtems_set_errno_and_return_minus_one( EINVAL );
+
   return 0;
 }
