@@ -2,14 +2,14 @@
  *  13.5.2 Dynamic Thread Scheduling Parameters Access,
  *         P1003.1c/Draft 10, p. 124
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2007.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: pthreadgetschedparam.c,v 1.6 2003/09/04 18:54:25 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -36,11 +36,9 @@ int pthread_getschedparam(
   if ( !policy || !param  )
     return EINVAL;
 
-  the_thread = _POSIX_Threads_Get( thread, &location );
+  the_thread = _Thread_Get( thread, &location );
   switch ( location ) {
-    case OBJECTS_ERROR:
-    case OBJECTS_REMOTE:
-      return ESRCH;
+
     case OBJECTS_LOCAL:
       api = the_thread->API_Extensions[ THREAD_API_POSIX ];
       if ( policy )
@@ -52,8 +50,14 @@ int pthread_getschedparam(
       }
       _Thread_Enable_dispatch();
       return 0;
+
+#if defined(RTEMS_MULTIPROCESSING)
+    case OBJECTS_REMOTE:
+#endif
+    case OBJECTS_ERROR:
+      break;
   }
 
-  return POSIX_BOTTOM_REACHED();
+  return ESRCH;
 
 }
