@@ -1,5 +1,12 @@
 /*
- *  $Id: setcancelstate.c,v 1.5 2004/04/16 10:01:03 ralf Exp $
+ *  COPYRIGHT (c) 1989-2009.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -13,13 +20,11 @@
 #include <rtems/score/chain.h>
 #include <rtems/score/isr.h>
 #include <rtems/score/thread.h>
-#include <rtems/score/wkspace.h>
 #include <rtems/posix/cancel.h>
 #include <rtems/posix/pthread.h>
 #include <rtems/posix/threadsup.h>
 
-/*PAGE
- *
+/*
  *  18.2.2 Setting Cancelability State, P1003.1c/Draft 10, p. 183
  */
 
@@ -28,7 +33,7 @@ int pthread_setcancelstate(
   int *oldstate
 )
 {
-  POSIX_API_Control                 *thread_support;
+  POSIX_API_Control *thread_support;
 
   /*
    *  Don't even think about deleting a resource from an ISR.
@@ -51,11 +56,11 @@ int pthread_setcancelstate(
     *oldstate = thread_support->cancelability_state;
     thread_support->cancelability_state = state;
 
-    if ( thread_support->cancelability_state == PTHREAD_CANCEL_ENABLE &&
-         thread_support->cancelability_type == PTHREAD_CANCEL_ASYNCHRONOUS &&
-         thread_support->cancelation_requested )
-      _POSIX_Threads_cancel_run( _Thread_Executing );
-  _Thread_Enable_dispatch();
+    _POSIX_Thread_Evaluate_cancellation_and_enable_dispatch(_Thread_Executing);
+
+  /*
+   *  _Thread_Enable_dispatch is invoked by above call.
+   */
 
   return 0;
 }
