@@ -17,7 +17,7 @@
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#define RCSID	"$Id: options.c,v 1.9 2007/09/16 04:13:48 ralf Exp $"
+#define RCSID	"$Id$"
 
 #include <ctype.h>
 #include <stdio.h>
@@ -162,116 +162,116 @@ static struct option_list *extra_options = NULL;
  */
 option_t general_options[] = {
     { "debug", o_int, &debug,
-      "Increase debugging level", OPT_INC|OPT_NOARG|1 },
+      "Increase debugging level", OPT_INC|OPT_NOARG|1, NULL, 0, 0 },
     { "-d", o_int, &debug,
-      "Increase debugging level", OPT_INC|OPT_NOARG|1 },
+      "Increase debugging level", OPT_INC|OPT_NOARG|1, NULL, 0, 0 },
     { "kdebug", o_int, &kdebugflag,
-      "Set kernel driver debug level" },
+      "Set kernel driver debug level", 0, NULL, 0, 0 },
     { "nodetach", o_bool, &nodetach,
-      "Don't detach from controlling tty", 1 },
+      "Don't detach from controlling tty", 1, NULL, 0, 0 },
     { "-detach", o_bool, &nodetach,
-      "Don't detach from controlling tty", 1 },
+      "Don't detach from controlling tty", 1, NULL, 0, 0 },
     { "updetach", o_bool, &updetach,
-      "Detach from controlling tty once link is up", 1 },
+      "Detach from controlling tty once link is up", 1, NULL, 0, 0 },
     { "holdoff", o_int, &holdoff,
-      "Set time in seconds before retrying connection" },
+      "Set time in seconds before retrying connection", 0, NULL, 0, 0 },
     { "idle", o_int, &idle_time_limit,
-      "Set time in seconds before disconnecting idle link" },
+      "Set time in seconds before disconnecting idle link", 0, NULL, 0, 0 },
     { "lock", o_bool, &lockflag,
-      "Lock serial device with UUCP-style lock file", 1 },
+      "Lock serial device with UUCP-style lock file", 1, NULL, 0, 0 },
     { "-all", o_special_noarg, noopt,
-      "Don't request/allow any LCP or IPCP options (useless)" },
+      "Don't request/allow any LCP or IPCP options (useless)", 0, NULL, 0, 0 },
     { "init", o_string, &initializer,
       "A program to initialize the device",
-      OPT_A2INFO | OPT_PRIVFIX, &initializer_info },
+      OPT_A2INFO | OPT_PRIVFIX, &initializer_info, 0, 0 },
     { "connect", o_string, &connect_script,
       "A program to set up a connection",
-      OPT_A2INFO | OPT_PRIVFIX, &connect_script_info },
+      OPT_A2INFO | OPT_PRIVFIX, &connect_script_info, 0, 0 },
     { "disconnect", o_string, &disconnect_script,
       "Program to disconnect serial device",
-      OPT_A2INFO | OPT_PRIVFIX, &disconnect_script_info },
+      OPT_A2INFO | OPT_PRIVFIX, &disconnect_script_info, 0, 0 },
     { "welcome", o_string, &welcomer,
       "Script to welcome client",
-      OPT_A2INFO | OPT_PRIVFIX, &welcomer_info },
+      OPT_A2INFO | OPT_PRIVFIX, &welcomer_info, 0, 0 },
     { "pty", o_string, &ptycommand,
       "Script to run on pseudo-tty master side",
-      OPT_A2INFO | OPT_PRIVFIX | OPT_DEVNAM, &ptycommand_info },
+      OPT_A2INFO | OPT_PRIVFIX | OPT_DEVNAM, &ptycommand_info, 0, 0 },
     { "notty", o_bool, &notty,
-      "Input/output is not a tty", OPT_DEVNAM | 1 },
+      "Input/output is not a tty", OPT_DEVNAM | 1, NULL, 0, 0 },
     { "record", o_string, &record_file,
-      "Record characters sent/received to file" },
+      "Record characters sent/received to file", 0, NULL, 0, 0 },
     { "maxconnect", o_int, &maxconnect,
-      "Set connection time limit", OPT_LLIMIT|OPT_NOINCR|OPT_ZEROINF },
+      "Set connection time limit", OPT_LLIMIT|OPT_NOINCR|OPT_ZEROINF, NULL, 0, 0 },
     { "crtscts", o_int, &crtscts,
-      "Set hardware (RTS/CTS) flow control", OPT_NOARG|OPT_VAL(1) },
+      "Set hardware (RTS/CTS) flow control", OPT_NOARG|OPT_VAL(1), NULL, 0, 0 },
     { "nocrtscts", o_int, &crtscts,
-      "Disable hardware flow control", OPT_NOARG|OPT_VAL(-1) },
+      "Disable hardware flow control", OPT_NOARG|OPT_VAL(-1), NULL, 0, 0 },
     { "-crtscts", o_int, &crtscts,
-      "Disable hardware flow control", OPT_NOARG|OPT_VAL(-1) },
+      "Disable hardware flow control", OPT_NOARG|OPT_VAL(-1), NULL, 0, 0 },
     { "cdtrcts", o_int, &crtscts,
-      "Set alternate hardware (DTR/CTS) flow control", OPT_NOARG|OPT_VAL(2) },
+      "Set alternate hardware (DTR/CTS) flow control", OPT_NOARG|OPT_VAL(2), NULL, 0, 0 },
     { "nocdtrcts", o_int, &crtscts,
-      "Disable hardware flow control", OPT_NOARG|OPT_VAL(-1) },
+      "Disable hardware flow control", OPT_NOARG|OPT_VAL(-1), NULL, 0, 0 },
     { "xonxoff", o_special_noarg, setxonxoff,
-      "Set software (XON/XOFF) flow control" },
+      "Set software (XON/XOFF) flow control", 0, NULL, 0, 0 },
     { "domain", o_special, setdomain,
-      "Add given domain name to hostname" },
+      "Add given domain name to hostname", 0, NULL, 0, 0 },
     { "mtu", o_int, &lcp_allowoptions[0].mru,
       "Set our MTU", OPT_LIMITS, NULL, MAXMRU, MINMRU },
     { "netmask", o_special, setnetmask,
-      "set netmask" },
+      "set netmask", 0, NULL, 0, 0 },
     { "modem", o_bool, &modem,
-      "Use modem control lines", 1 },
+      "Use modem control lines", 1, NULL, 0, 0 },
     { "local", o_bool, &modem,
-      "Don't use modem control lines" },
+      "Don't use modem control lines", 0, NULL, 0, 0 },
     { "file", o_special, readfile,
-      "Take options from a file", OPT_PREPASS },
+      "Take options from a file", OPT_PREPASS, NULL, 0, 0 },
     { "call", o_special, callfile,
-      "Take options from a privileged file", OPT_PREPASS },
+      "Take options from a privileged file", OPT_PREPASS, NULL, 0, 0 },
     { "persist", o_bool, &persist,
-      "Keep on reopening connection after close", 1 },
+      "Keep on reopening connection after close", 1, NULL, 0, 0 },
     { "nopersist", o_bool, &persist,
-      "Turn off persist option" },
+      "Turn off persist option", 0, NULL, 0, 0 },
     { "demand", o_bool, &demand,
-      "Dial on demand", OPT_INITONLY | 1, &persist },
+      "Dial on demand", OPT_INITONLY | 1, &persist, 0, 0 },
     { "sync", o_bool, &sync_serial,
-      "Use synchronous HDLC serial encoding", 1 },
+      "Use synchronous HDLC serial encoding", 1, NULL, 0, 0 },
     { "logfd", o_int, &log_to_fd,
-      "Send log messages to this file descriptor" },
+      "Send log messages to this file descriptor", 0, NULL, 0, 0 },
     { "logfile", o_special, setlogfile,
-      "Append log messages to this file" },
+      "Append log messages to this file", 0, NULL, 0, 0 },
     { "nolog", o_int, &log_to_fd,
       "Don't send log messages to any file",
-      OPT_NOARG | OPT_VAL(-1) },
+      OPT_NOARG | OPT_VAL(-1), NULL, 0, 0 },
     { "nologfd", o_int, &log_to_fd,
       "Don't send log messages to any file descriptor",
-      OPT_NOARG | OPT_VAL(-1) },
+      OPT_NOARG | OPT_VAL(-1), NULL, 0, 0 },
     { "linkname", o_string, linkname,
       "Set logical name for link",
-      OPT_PRIV|OPT_STATIC, NULL, MAXPATHLEN },
+      OPT_PRIV|OPT_STATIC, NULL, MAXPATHLEN, 0 },
     { "maxfail", o_int, &maxfail,
-      "Maximum number of unsuccessful connection attempts to allow" },
+      "Maximum number of unsuccessful connection attempts to allow", 0, NULL, 0, 0 },
     { "ktune", o_bool, &tune_kernel,
-      "Alter kernel settings as necessary", 1 },
+      "Alter kernel settings as necessary", 1, NULL, 0, 0 },
     { "noktune", o_bool, &tune_kernel,
-      "Don't alter kernel settings", 0 },
+      "Don't alter kernel settings", 0, NULL, 0, 0 },
     { "connect-delay", o_int, &connect_delay,
-      "Maximum time (in ms) to wait after connect script finishes" },
+      "Maximum time (in ms) to wait after connect script finishes", 0, NULL, 0, 0 },
 #ifdef PLUGIN
     { "plugin", o_special, loadplugin,
-      "Load a plug-in module into pppd", OPT_PRIV },
+      "Load a plug-in module into pppd", OPT_PRIV, NULL, 0, 0 },
 #endif
 
 #ifdef PPP_FILTER
     { "pdebug", o_int, &dflag,
-      "libpcap debugging" },
+      "libpcap debugging", 0, NULL, 0, 0 },
     { "pass-filter", 1, setpassfilter,
-      "set filter for packets to pass" },
+      "set filter for packets to pass", 0, NULL, 0, 0 },
     { "active-filter", 1, setactivefilter,
-      "set filter for active pkts" },
+      "set filter for active pkts", 0, NULL, 0, 0 },
 #endif
 
-    { NULL }
+    { NULL, 0, NULL, NULL, 0,  NULL, 0, 0 }
 };
 
 #ifndef IMPLEMENTATION
@@ -302,9 +302,9 @@ See pppd(8) for more options.\n\
  * processing a few options, so error messages are suppressed.
  */
 int
-parse_args(argc, argv)
-    int argc;
-    char **argv;
+parse_args(
+    int argc,
+    char **argv)
 {
     char *arg;
     option_t *opt;
@@ -392,11 +392,11 @@ scan_args(argc, argv)
  * and interpret them.
  */
 int
-options_from_file(filename, must_exist, check_prot, priv)
-    char *filename;
-    int must_exist;
-    int check_prot;
-    int priv;
+options_from_file(
+    char *filename,
+    int must_exist,
+    int check_prot,
+    int priv)
 {
     FILE *f;
     int i, newline, ret, err;
@@ -478,7 +478,7 @@ err:
  * and if so, interpret options from it.
  */
 int
-options_from_user()
+options_from_user(void)
 {
     return 0;
 }
@@ -488,7 +488,7 @@ options_from_user()
  * device, and if so, interpret options from it.
  */
 int
-options_for_tty()
+options_for_tty(void)
 {
     char *dev, *path, *p;
     int ret;
@@ -517,9 +517,9 @@ options_for_tty()
  * options_from_list - process a string of options in a wordlist.
  */
 int
-options_from_list(w, priv)
-    struct wordlist *w;
-    int priv;
+options_from_list(
+    struct wordlist *w,
+    int priv)
 {
     char *argv[MAXARGS];
     option_t *opt;
@@ -579,8 +579,7 @@ err:
  * This could be optimized by using a hash table.
  */
 static option_t *
-find_option(name)
-    char *name;
+find_option(char *name)
 {
     option_t *opt;
     struct option_list *list;
@@ -608,9 +607,9 @@ find_option(name)
  * process_option - process one new-style option.
  */
 static int
-process_option(opt, argv)
-    option_t *opt;
-    char **argv;
+process_option(
+    option_t *opt,
+    char **argv)
 {
     uint32_t v;
     int iv, a;
@@ -743,8 +742,8 @@ process_option(opt, argv)
  * n_arguments - tell how many arguments an option takes
  */
 static int
-n_arguments(opt)
-    option_t *opt;
+n_arguments(
+    option_t *opt)
 {
     return (opt->type == o_bool || opt->type == o_special_noarg
 	    || (opt->flags & OPT_NOARG))? 0: 1;
@@ -754,8 +753,8 @@ n_arguments(opt)
  * add_options - add a list of options to the set we grok.
  */
 void
-add_options(opt)
-    option_t *opt;
+add_options(
+    option_t *opt)
 {
     struct option_list *list;
 
@@ -771,7 +770,7 @@ add_options(opt)
  * usage - print out a message telling how to use the program.
  */
 static void
-usage()
+usage(void)
 {
     if (pppd_phase == PHASE_INITIALIZE)
 	fprintf(stderr, usage_string, VERSION, PATCHLEVEL, IMPLEMENTATION,
@@ -813,11 +812,11 @@ option_error __V((char *fmt, ...))
  * \<newline> is ignored.
  */
 int
-getword(f, word, newlinep, filename)
-    FILE *f;
-    char *word;
-    int *newlinep;
-    char *filename;
+getword(
+    FILE *f,
+    char *word,
+    int *newlinep,
+    char *filename)
 {
     int c, len, escape;
     int quoted, comment;
@@ -1056,10 +1055,10 @@ getword(f, word, newlinep, filename)
  * number_option - parse an unsigned numeric parameter for an option.
  */
 static int
-number_option(str, valp, base)
-    char *str;
-    uint32_t *valp;
-    int base;
+number_option(
+    char *str,
+    uint32_t *valp,
+    int base)
 {
     char *ptr;
 
@@ -1079,9 +1078,9 @@ number_option(str, valp, base)
  * if there is an error.
  */
 int
-int_option(str, valp)
-    char *str;
-    int *valp;
+int_option(
+    char *str,
+    int *valp)
 {
     uint32_t v;
 
@@ -1100,8 +1099,8 @@ int_option(str, valp)
  * readfile - take commands from a file.
  */
 static int
-readfile(argv)
-    char **argv;
+readfile(
+    char **argv)
 {
     return options_from_file(*argv, 1, 1, privileged_option);
 }
@@ -1111,8 +1110,8 @@ readfile(argv)
  * Name may not contain /../, start with / or ../, or end in /..
  */
 static int
-callfile(argv)
-    char **argv;
+callfile(
+    char **argv)
 {
     char *fname, *arg, *p;
     int l, ok;
@@ -1154,8 +1153,8 @@ callfile(argv)
  * setpdebug - Set libpcap debugging level.
  */
 static int
-setpdebug(argv)
-    char **argv;
+setpdebug(
+    char **argv)
 {
     return int_option(*argv, &dflag);
 }
@@ -1164,12 +1163,12 @@ setpdebug(argv)
  * setpassfilter - Set the pass filter for packets
  */
 static int
-setpassfilter(argv)
-    char **argv;
+setpassfilter(
+    char **argv)
 {
     pc.linktype = DLT_PPP;
     pc.snapshot = PPP_HDRLEN;
- 
+
     if (pcap_compile(&pc, &pass_filter, *argv, 1, netmask) == 0)
 	return 1;
     option_error("error in pass-filter expression: %s\n", pcap_geterr(&pc));
@@ -1180,12 +1179,12 @@ setpassfilter(argv)
  * setactivefilter - Set the active filter for packets
  */
 static int
-setactivefilter(argv)
-    char **argv;
+setactivefilter(
+    char **argv)
 {
     pc.linktype = DLT_PPP;
     pc.snapshot = PPP_HDRLEN;
- 
+
     if (pcap_compile(&pc, &active_filter, *argv, 1, netmask) == 0)
 	return 1;
     option_error("error in active-filter expression: %s\n", pcap_geterr(&pc));
@@ -1197,8 +1196,8 @@ setactivefilter(argv)
  * noopt - Disable all options.
  */
 static int
-noopt(argv)
-    char **argv;
+noopt(
+    char **argv)
 {
     BZERO((char *) &lcp_wantoptions[0], sizeof (struct lcp_options));
     BZERO((char *) &lcp_allowoptions[0], sizeof (struct lcp_options));
@@ -1209,11 +1208,11 @@ noopt(argv)
 }
 
 /*
- * setdomain - Set domain name to append to hostname 
+ * setdomain - Set domain name to append to hostname
  */
 static int
-setdomain(argv)
-    char **argv;
+setdomain(
+    char **argv)
 {
     if (!privileged_option) {
 	option_error("using the domain option requires root privilege");
@@ -1234,8 +1233,8 @@ setdomain(argv)
  * setspeed - Set the speed.
  */
 static int
-setspeed(arg)
-    char *arg;
+setspeed(
+    char *arg)
 {
   long     spd;
   uint32_t ret      = 1;
@@ -1289,8 +1288,8 @@ setspeed(arg)
  * setdevname - Set the device name.
  */
 static int
-setdevname(cp)
-    char *cp;
+setdevname(
+    char *cp)
 {
     struct stat statbuf;
     char dev[MAXPATHLEN];
@@ -1336,7 +1335,7 @@ setdevname(cp)
     default_device = 0;
     devnam_info.priv = privileged_option;
     devnam_info.source = option_source;
-  
+
     return 1;
 }
 
@@ -1345,14 +1344,14 @@ setdevname(cp)
  * setipaddr - Set the IP address
  */
 static int
-setipaddr(arg)
-    char *arg;
+setipaddr(
+    char *arg)
 {
     struct hostent *hp;
     char *colon;
     uint32_t local, remote;
     ipcp_options *wo = &ipcp_wantoptions[0];
-  
+
     /*
      * IP address pair separated by ":".
      */
@@ -1360,7 +1359,7 @@ setipaddr(arg)
 	return 0;
     if (prepass)
 	return 1;
-  
+
     /*
      * If colon first character, then no local addr.
      */
@@ -1382,7 +1381,7 @@ setipaddr(arg)
 	    wo->ouraddr = local;
 	*colon = ':';
     }
-  
+
     /*
      * If colon last character, then no remote addr.
      */
@@ -1413,8 +1412,8 @@ setipaddr(arg)
  * setnetmask - set the netmask to be used on the interface.
  */
 static int
-setnetmask(argv)
-    char **argv;
+setnetmask(
+    char **argv)
 {
     uint32_t mask, b;
     int n, ok;
@@ -1458,8 +1457,8 @@ setnetmask(argv)
 }
 
 static int
-setxonxoff(argv)
-    char **argv;
+setxonxoff(
+    char **argv)
 {
     lcp_wantoptions[0].asyncmap |= 0x000A0000;	/* escape ^S and ^Q */
     lcp_wantoptions[0].neg_asyncmap = 1;
@@ -1469,8 +1468,8 @@ setxonxoff(argv)
 }
 
 static int
-setlogfile(argv)
-    char **argv;
+setlogfile(
+    char **argv)
 {
     int fd, err;
 
@@ -1492,8 +1491,8 @@ setlogfile(argv)
 
 #ifdef PLUGIN
 static int
-loadplugin(argv)
-    char **argv;
+loadplugin(
+    char **argv)
 {
     char *arg = *argv;
     void *handle;
