@@ -16,12 +16,13 @@
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  *
- * $Id: pppd.h,v 1.16 2007/09/16 04:13:48 ralf Exp $
+ * $Id$
  */
 
 #ifndef __PPPD_H__
 #define __PPPD_H__
 
+#include <stdbool.h>		/* bool */
 #include <stdio.h>		/* for FILE */
 #include <limits.h>		/* for NGROUPS_MAX */
 #include <sys/param.h>		/* for MAXPATHLEN and BSD4_4, if defined */
@@ -29,7 +30,7 @@
 #include <sys/time.h>		/* for struct timeval */
 #include <net/ppp_defs.h>
 #include <rtems/rtemsdialer.h>
-#include <rtems/stdint.h>
+#include <stdint.h>
 
 #if defined(__STDC__)
 #include <stdarg.h>
@@ -59,8 +60,6 @@
  * Option descriptor structure.
  */
 
-typedef unsigned char	bool;
-
 enum opt_type {
 	o_special_noarg = 0,
 	o_special = 1,
