@@ -1,9 +1,13 @@
 /**
- * @file rtems/score/types.h
+ * @file
+ *
+ * @ingroup ScoreCPU
+ *
+ * @brief ARM architecture types API.
  */
 
 /*
- *  $Id: types.h,v 1.13 2006/11/17 05:57:26 ralf Exp $
+ *  $Id$
  *
  *  This include file contains type definitions pertaining to the
  *  arm processor family.
@@ -22,24 +26,32 @@
 
 #ifndef ASM
 
-#include <rtems/stdint.h>
+#include <stdbool.h>
+#include <stdint.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+/**
+ * @addtogroup ScoreCPU
+ *
+ * @{
+ */
+
 /*
  *  This section defines the basic types for this processor.
  */
 
-typedef uint32_t         boolean;            /* Boolean value   */
 typedef uint16_t         Priority_Bit_map_control;
 
-typedef float              single_precision;   /* single precision float */
-typedef double             double_precision;   /* double precision float */
+#ifdef RTEMS_DEPRECATED_TYPES
+typedef bool		boolean;            /* Boolean value   */
+typedef float           single_precision;   /* single precision float */
+typedef double          double_precision;   /* double precision float */
+#endif
 
-typedef void               arm_cpu_isr;
-typedef void            ( *arm_cpu_isr_entry )( void );
+/** @} */
 
 #ifdef __cplusplus
 }
