@@ -13,7 +13,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: types.h,v 1.13 2006/11/17 05:57:50 ralf Exp $
+ *  $Id$
  */
 
 #ifndef _RTEMS_SCORE_TYPES_H
@@ -21,7 +21,8 @@
 
 #ifndef ASM
 
-#include <rtems/stdint.h>
+#include <stdbool.h>
+#include <stdint.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -34,14 +35,6 @@ extern "C" {
 /** This defines the type for a priority bit map entry. */
 typedef uint16_t Priority_Bit_map_control;
 
-/** This defines the type for a Boolean value, */
-typedef uint32_t boolean;     /* Boolean value   */
-
-/** This defines the type for a single precision float. */
-typedef float          single_precision;
-/** This defines the type for a double precision float. */
-typedef double         double_precision;
-
 /** This defines the return type for an ISR entry point. */
 typedef void no_cpu_isr;
 
