@@ -3,7 +3,7 @@
  *  On-Line Applications Research Corporation (OAR).
  *  All rights reserved.
  *
- *  $Id: base.h,v 1.5 2002/01/17 21:47:47 joel Exp $
+ *  $Id$
  */
 
 #ifndef __PDL2AMI_h
@@ -12,10 +12,6 @@
 #include "system.h"
 #include "chain.h"
 
-#ifndef EXTERN 
-#define EXTERN extern
-#endif
-
 /*
  *  Paragraph size should be kept down because it is allocated for each
  *  Line_Control.  If this number is large, the memory requirements for
@@ -27,7 +23,7 @@
 
 #define NUMBER_ELEMENTS( _x ) (sizeof(_x) / sizeof _x[0])
 
-void exit_application( 
+void exit_application(
   int status
 );
 
@@ -58,14 +54,14 @@ int CheckSections( void );
 
 void GenerateLists( void );
 
-void GenerateAList( 
+void GenerateAList(
   char          *section,
   Chain_Control *the_list
 );
 
 void LookForInternalInconsistencies( void );
 
-int Match_Argument( 
+int Match_Argument(
   char  **array,
   int     entries,
   char   *users
@@ -93,21 +89,10 @@ void PrintFile(
    char *out
 );
 
-void DumpList( 
+void DumpList(
   Chain_Control  *the_list
 );
 
 void ReleaseFile();
 
-EXTERN boolean          Verbose;                 /* status/debug msgs */
-EXTERN boolean          BlankAsWarnings;
-EXTERN Chain_Control    Lines;
-
-EXTERN int              NumberOfAttributes;
-EXTERN int              NumberOfAssociations;
-EXTERN int              NumberOfAbstractTypes;
-EXTERN int              NumberOfDataItems;
-EXTERN int              NumberOfMethods;
-EXTERN int              NumberOfTasks;
-
 #endif
