@@ -15,7 +15,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: task1.c,v 1.11 2004/03/30 11:18:29 ralf Exp $
+ *  $Id$
  */
 
 #include "system.h"
@@ -25,7 +25,7 @@ rtems_task Test_task1(
 )
 {
   char              receive_buffer[16];
-  uint32_t    size;
+  size_t            size;
   rtems_status_code status;
 
   puts( "Getting QID of message queue" );
@@ -41,7 +41,7 @@ rtems_task Test_task1(
   puts( "Attempting to receive message ..." );
   status = rtems_message_queue_receive(
     Queue_id[ 1 ],
-    (long (*)[4])receive_buffer,
+    receive_buffer,
     &size,
     RTEMS_DEFAULT_OPTIONS,
     RTEMS_NO_TIMEOUT
