@@ -17,7 +17,7 @@
  *  the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: init.c,v 1.2 2007/08/21 10:49:31 ccj Exp $
+ *  $Id$
  */
 
 #define CONFIGURE_INIT
@@ -30,17 +30,17 @@
 #include <rtems/capture-cli.h>
 #include <rtems/monitor.h>
 
-void setup_tasks_to_watch ();
-
 volatile int can_proceed = 1;
 
 rtems_task Init(
   rtems_task_argument ignored
 )
 {
+#if BSP_SMALL_MEMORY
+  printf("NO Capture Engine. MEMORY TOO SMALL");
+#else
   rtems_task_priority old_priority;
   rtems_mode          old_mode;
-  rtems_event_set     out;
 
   /* lower the task priority to allow created tasks to execute */
 
@@ -57,17 +57,9 @@ rtems_task Init(
 
   rtems_monitor_init (0);
   rtems_capture_cli_init (0);
-  
+
   setup_tasks_to_watch ();
 
   rtems_task_delete (RTEMS_SELF);
-
-  printf( "\nblocking main\n" );
-
-  rtems_event_receive (RTEMS_EVENT_1, RTEMS_WAIT | RTEMS_EVENT_ANY,
-                       0, &out);
-
-  printf( "\n*** END OF UNLIMITED TASK TEST ***\n" );
-  exit( 0 );
+#endif
 }
-
