@@ -7,14 +7,14 @@
  *
  *  Output parameters:  NONE
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2009.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: tasks.c,v 1.12 2007/05/10 19:31:36 joel Exp $
+ *  $Id$
  */
 
 #include "system.h"
@@ -31,13 +31,14 @@ rtems_task Test_task(
   status = rtems_task_ident( RTEMS_SELF, RTEMS_SEARCH_ALL_NODES, &tid );
   task_index = task_number( tid );
   for ( ; ; ) {
-    status = rtems_clock_get( RTEMS_CLOCK_GET_TOD, &time );
+    status = rtems_clock_get_tod( &time );
     if ( time.second >= 35 ) {
       puts( "*** END OF CLOCK TICK TEST ***" );
       rtems_test_exit( 0 );
     }
     put_name( Task_name[ task_index ], FALSE );
-    print_time( " - rtems_clock_get - ", &time, "\n" );
-    status = rtems_task_wake_after( task_index * 5 * get_ticks_per_second() );
+    print_time( " - rtems_clock_get_tod - ", &time, "\n" );
+    status = rtems_task_wake_after(
+      task_index * 5 * rtems_clock_get_ticks_per_second() );
   }
 }
